# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/book-reader.svg' card_color='#22a7f0' width='50' height='50' style='vertical-align:bottom'/> Spelling
Let Neon help you spell words

## About 
Neon can spell any word which is understood by speech-to-text.

## Examples 
* "How do you spell aardvark?"
* "Spell succotash."
* "How do you spell bureacracy?"
* "Spell omnipotence."

## Credits 
[Mycroft AI](https://github.com/MycroftAI)
[NeonDaniel](https://github.com/NeonDaniel)

## Category
**Information**

## Tags
#spell
#spelling
